fnss.topologies.topology.Topology.remove_edge — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.topologies.topology.Topology.remove_edge

`Topology.` `remove_edge`(u, v)

  Remove the edge between u and v.

  Parameters : | u,v: nodes : Remove the edge between nodes u and v.
  Raises : | NetworkXError : If there is not an edge between u and v.

  See also

  `remove_edges_from`
    remove a collection of edges

  Examples

      >>> G = nx.Graph()   # or DiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> G.remove_edge(0,1)
      >>> e = (1,2)
      >>> G.remove_edge(*e) # unpacks e from an edge tuple
      >>> e = (2,3,{'weight':7}) # an edge with attribute data
      >>> G.remove_edge(*e[:2]) # select first part of edge tuple

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »